@@ -1,5 +1,5 @@
 from pathlib import Path
-from typing import Iterator, List, Union
+from typing import AsyncIterator, Iterator, List, Union
 
 from pydantic import Field
 
@@ -33,3 +33,17 @@ class CSVKnowledgeBase(AgentKnowledge):
             if _csv_path.name in self.exclude_files:
                 return
             yield self.reader.read(file=_csv_path)
+
+    @property
+    async def async_document_lists(self) -> AsyncIterator[List[Document]]:
+        _csv_path: Path = Path(self.path) if isinstance(self.path, str) else self.path
+
+        if _csv_path.exists() and _csv_path.is_dir():
+            for _csv in _csv_path.glob("**/*.csv"):
+                if _csv.name in self.exclude_files:
+                    continue
+                yield await self.reader.async_read(file=_csv)
+        elif _csv_path.exists() and _csv_path.is_file() and _csv_path.suffix == ".csv":
+            if _csv_path.name in self.exclude_files:
+                return
+            yield await self.reader.async_read(file=_csv_path)
