@@ -1,6 +1,6 @@
 import json
 from collections.abc import AsyncIterator
-from dataclasses import dataclass
+from dataclasses import asdict, dataclass
 from os import getenv
 from typing import Any, Dict, List, Optional, Type, Union
 
@@ -11,24 +11,46 @@ from agno.models.base import Model
 from agno.models.message import Citations, DocumentCitation, Message, UrlCitation
 from agno.models.response import ModelResponse
 from agno.utils.log import log_error, log_warning
-from agno.utils.models.claude import format_messages
+from agno.utils.models.claude import MCPServerConfiguration, format_messages
 
 try:
-    from anthropic import Anthropic as AnthropicClient
-    from anthropic import APIConnectionError, APIStatusError, RateLimitError
-    from anthropic import AsyncAnthropic as AsyncAnthropicClient
+    from anthropic import (
+        Anthropic as AnthropicClient,
+    )
+    from anthropic import (
+        APIConnectionError,
+        APIStatusError,
+        RateLimitError,
+    )
+    from anthropic import (
+        AsyncAnthropic as AsyncAnthropicClient,
+    )
     from anthropic.types import (
         CitationPageLocation,
         CitationsWebSearchResultLocation,
         ContentBlockDeltaEvent,
         ContentBlockStartEvent,
         ContentBlockStopEvent,
-        MessageDeltaEvent,
+        # MessageDeltaEvent,  # Currently broken
         MessageStopEvent,
     )
-    from anthropic.types import Message as AnthropicMessage
-except ImportError:
-    raise ImportError("`anthropic` not installed. Please install using `pip install anthropic`")
+    from anthropic.types import (
+        Message as AnthropicMessage,
+    )
+except ImportError as e:
+    raise ImportError("`anthropic` not installed. Please install it with `pip install anthropic`") from e
+
+# Import Beta types
+try:
+    from anthropic.types.beta import (
+        BetaMessage,
+        BetaRawContentBlockDeltaEvent,
+        BetaTextDelta,
+    )
+except ImportError as e:
+    raise ImportError(
+        "`anthropic` not installed or missing beta components. Please install with `pip install anthropic`"
+    ) from e
 
 
 @dataclass
@@ -50,10 +72,14 @@ class Claude(Model):
     stop_sequences: Optional[List[str]] = None
     top_p: Optional[float] = None
     top_k: Optional[int] = None
+    cache_system_prompt: Optional[bool] = False
+    extended_cache_time: Optional[bool] = False
     request_params: Optional[Dict[str, Any]] = None
+    mcp_servers: Optional[List[MCPServerConfiguration]] = None
 
     # Client parameters
     api_key: Optional[str] = None
+    default_headers: Optional[Dict[str, Any]] = None
     client_params: Optional[Dict[str, Any]] = None
 
     # Anthropic clients
@@ -69,9 +95,12 @@ class Claude(Model):
 
         # Add API key to client parameters
         client_params["api_key"] = self.api_key
+
         # Add additional client parameters
         if self.client_params is not None:
             client_params.update(self.client_params)
+        if self.default_headers is not None:
+            client_params["default_headers"] = self.default_headers
         return client_params
 
     def get_client(self) -> AnthropicClient:
@@ -114,6 +143,10 @@ class Claude(Model):
             _request_params["top_p"] = self.top_p
         if self.top_k:
             _request_params["top_k"] = self.top_k
+        if self.mcp_servers:
+            _request_params["mcp_servers"] = [
+                {k: v for k, v in asdict(server).items() if v is not None} for server in self.mcp_servers
+            ]
         if self.request_params:
             _request_params.update(self.request_params)
         return _request_params
@@ -131,7 +164,16 @@ class Claude(Model):
             Dict[str, Any]: The request keyword arguments.
         """
         request_kwargs = self.request_kwargs.copy()
-        request_kwargs["system"] = system_message
+        if system_message:
+            if self.cache_system_prompt:
+                cache_control = (
+                    {"type": "ephemeral", "ttl": "1h"}
+                    if self.extended_cache_time is not None and self.extended_cache_time is True
+                    else {"type": "ephemeral"}
+                )
+                request_kwargs["system"] = [{"text": system_message, "type": "text", "cache_control": cache_control}]
+            else:
+                request_kwargs["system"] = [{"text": system_message, "type": "text"}]
 
         if tools:
             request_kwargs["tools"] = self._format_tools_for_model(tools)
@@ -190,7 +232,7 @@ class Claude(Model):
         response_format: Optional[Union[Dict, Type[BaseModel]]] = None,
         tools: Optional[List[Dict[str, Any]]] = None,
         tool_choice: Optional[Union[str, Dict[str, Any]]] = None,
-    ) -> AnthropicMessage:
+    ) -> Union[AnthropicMessage, BetaMessage]:
         """
         Send a request to the Anthropic API to generate a response.
         """
@@ -198,11 +240,18 @@ class Claude(Model):
             chat_messages, system_message = format_messages(messages)
             request_kwargs = self._prepare_request_kwargs(system_message, tools)
 
-            return self.get_client().messages.create(
-                model=self.id,
-                messages=chat_messages,  # type: ignore
-                **request_kwargs,
-            )
+            if self.mcp_servers is not None:
+                return self.get_client().beta.messages.create(
+                    model=self.id,
+                    messages=chat_messages,  # type: ignore
+                    **self.request_kwargs,
+                )
+            else:
+                return self.get_client().messages.create(
+                    model=self.id,
+                    messages=chat_messages,  # type: ignore
+                    **request_kwargs,
+                )
         except APIConnectionError as e:
             log_error(f"Connection error while calling Claude API: {str(e)}")
             raise ModelProviderError(message=e.message, model_name=self.name, model_id=self.id) from e
@@ -243,15 +292,26 @@ class Claude(Model):
         request_kwargs = self._prepare_request_kwargs(system_message, tools)
 
         try:
-            return (
-                self.get_client()
-                .messages.stream(
-                    model=self.id,
-                    messages=chat_messages,  # type: ignore
-                    **request_kwargs,
+            if self.mcp_servers is not None:
+                return (
+                    self.get_client()
+                    .beta.messages.stream(
+                        model=self.id,
+                        messages=chat_messages,  # type: ignore
+                        **request_kwargs,
+                    )
+                    .__enter__()
+                )
+            else:
+                return (
+                    self.get_client()
+                    .messages.stream(
+                        model=self.id,
+                        messages=chat_messages,  # type: ignore
+                        **request_kwargs,
+                    )
+                    .__enter__()
                 )
-                .__enter__()
-            )
         except APIConnectionError as e:
             log_error(f"Connection error while calling Claude API: {str(e)}")
             raise ModelProviderError(message=e.message, model_name=self.name, model_id=self.id) from e
@@ -273,7 +333,7 @@ class Claude(Model):
         response_format: Optional[Union[Dict, Type[BaseModel]]] = None,
         tools: Optional[List[Dict[str, Any]]] = None,
         tool_choice: Optional[Union[str, Dict[str, Any]]] = None,
-    ) -> AnthropicMessage:
+    ) -> Union[AnthropicMessage, BetaMessage]:
         """
         Send an asynchronous request to the Anthropic API to generate a response.
         """
@@ -281,11 +341,18 @@ class Claude(Model):
             chat_messages, system_message = format_messages(messages)
             request_kwargs = self._prepare_request_kwargs(system_message, tools)
 
-            return await self.get_async_client().messages.create(
-                model=self.id,
-                messages=chat_messages,  # type: ignore
-                **request_kwargs,
-            )
+            if self.mcp_servers is not None:
+                return await self.get_async_client().beta.messages.create(
+                    model=self.id,
+                    messages=chat_messages,  # type: ignore
+                    **self.request_kwargs,
+                )
+            else:
+                return await self.get_async_client().messages.create(
+                    model=self.id,
+                    messages=chat_messages,  # type: ignore
+                    **request_kwargs,
+                )
         except APIConnectionError as e:
             log_error(f"Connection error while calling Claude API: {str(e)}")
             raise ModelProviderError(message=e.message, model_name=self.name, model_id=self.id) from e
@@ -325,13 +392,23 @@ class Claude(Model):
         try:
             chat_messages, system_message = format_messages(messages)
             request_kwargs = self._prepare_request_kwargs(system_message, tools)
-            async with self.get_async_client().messages.stream(
-                model=self.id,
-                messages=chat_messages,  # type: ignore
-                **request_kwargs,
-            ) as stream:
-                async for chunk in stream:
-                    yield chunk
+
+            if self.mcp_servers is not None:
+                async with self.get_async_client().beta.messages.stream(
+                    model=self.id,
+                    messages=chat_messages,  # type: ignore
+                    **request_kwargs,
+                ) as stream:
+                    async for chunk in stream:
+                        yield chunk
+            else:
+                async with self.get_async_client().messages.stream(
+                    model=self.id,
+                    messages=chat_messages,  # type: ignore
+                    **request_kwargs,
+                ) as stream:
+                    async for chunk in stream:  # type: ignore
+                        yield chunk
         except APIConnectionError as e:
             log_error(f"Connection error while calling Claude API: {str(e)}")
             raise ModelProviderError(message=e.message, model_name=self.name, model_id=self.id) from e
@@ -449,12 +526,23 @@ class Claude(Model):
 
         # Add usage metrics
         if response.usage is not None:
-            model_response.response_usage = response.usage
+            usage_dict = {
+                "input_tokens": response.usage.input_tokens,
+                "output_tokens": response.usage.output_tokens,
+            }
+
+            if hasattr(response.usage, "cache_creation_input_tokens") and response.usage.cache_creation_input_tokens:
+                usage_dict["cache_write_tokens"] = response.usage.cache_creation_input_tokens
+
+            if hasattr(response.usage, "cache_read_input_tokens") and response.usage.cache_read_input_tokens:
+                usage_dict["cached_tokens"] = response.usage.cache_read_input_tokens
+
+            model_response.response_usage = usage_dict
 
         return model_response
 
     def parse_provider_response_delta(
-        self, response: Union[ContentBlockDeltaEvent, ContentBlockStopEvent, MessageDeltaEvent]
+        self, response: Union[ContentBlockStartEvent, ContentBlockDeltaEvent, ContentBlockStopEvent, MessageStopEvent]
     ) -> ModelResponse:
         """
         Parse the Claude streaming response into ModelProviderResponse objects.
@@ -509,7 +597,7 @@ class Claude(Model):
         elif isinstance(response, MessageStopEvent):
             model_response.content = ""
             model_response.citations = Citations(raw=[], urls=[], documents=[])
-            for block in response.message.content:
+            for block in response.message.content:  # type: ignore
                 citations = getattr(block, "citations", None)
                 if not citations:
                     continue
@@ -523,7 +611,30 @@ class Claude(Model):
                         model_response.citations.documents.append(  # type: ignore
                             DocumentCitation(document_title=citation.document_title, cited_text=citation.cited_text)
                         )
-            if response.message.usage is not None:
-                model_response.response_usage = response.message.usage
+
+        if hasattr(response, "usage") and response.usage is not None:
+            usage_dict = {
+                "input_tokens": response.usage.input_tokens or 0,
+                "output_tokens": response.usage.output_tokens or 0,
+            }
+
+            if hasattr(response.usage, "cache_creation_input_tokens") and response.usage.cache_creation_input_tokens:
+                usage_dict["cache_write_tokens"] = response.usage.cache_creation_input_tokens
+
+            if hasattr(response.usage, "cache_read_input_tokens") and response.usage.cache_read_input_tokens:
+                usage_dict["cached_tokens"] = response.usage.cache_read_input_tokens
+
+            model_response.response_usage = usage_dict
+
+        # Capture the Beta response
+        try:
+            if (
+                isinstance(response, BetaRawContentBlockDeltaEvent)
+                and isinstance(response.delta, BetaTextDelta)
+                and response.delta.text is not None
+            ):
+                model_response.content = response.delta.text
+        except Exception as e:
+            log_error(f"Error parsing Beta response: {e}")
 
         return model_response
