@@ -25,7 +25,6 @@ try:
         ChoiceDelta,
         ChoiceDeltaToolCall,
     )
-    from openai.types.chat.parsed_chat_completion import ParsedChatCompletion
 except (ImportError, ModuleNotFoundError):
     raise ImportError("`openai` not installed. Please install using `pip install openai`")
 
@@ -66,6 +65,7 @@ class OpenAIChat(Model):
     extra_headers: Optional[Any] = None
     extra_query: Optional[Any] = None
     request_params: Optional[Dict[str, Any]] = None
+    role_map: Optional[Dict[str, str]] = None
 
     # Client parameters
     api_key: Optional[str] = None
@@ -79,7 +79,7 @@ class OpenAIChat(Model):
     client_params: Optional[Dict[str, Any]] = None
 
     # The role to map the message role to.
-    role_map = {
+    default_role_map = {
         "system": "developer",
         "user": "user",
         "assistant": "assistant",
@@ -167,7 +167,6 @@ class OpenAIChat(Model):
             "modalities": self.modalities,
             "audio": self.audio,
             "presence_penalty": self.presence_penalty,
-            "response_format": response_format,
             "seed": self.seed,
             "stop": self.stop,
             "temperature": self.temperature,
@@ -178,6 +177,25 @@ class OpenAIChat(Model):
             "metadata": self.metadata,
         }
 
+        # Handle response format - always use JSON schema approach
+        if response_format is not None:
+            if isinstance(response_format, type) and issubclass(response_format, BaseModel):
+                # Convert Pydantic to JSON schema for regular endpoint
+                from agno.utils.models.schema_utils import get_response_schema_for_provider
+
+                schema = get_response_schema_for_provider(response_format, "openai")
+                base_params["response_format"] = {
+                    "type": "json_schema",
+                    "json_schema": {
+                        "name": response_format.__name__,
+                        "schema": schema,
+                        "strict": True,
+                    },
+                }
+            else:
+                # Handle other response format types (like {"type": "json_object"})
+                base_params["response_format"] = response_format
+
         # Filter out None values
         request_params = {k: v for k, v in base_params.items() if v is not None}
 
@@ -236,7 +254,7 @@ class OpenAIChat(Model):
             Dict[str, Any]: The formatted message.
         """
         message_dict: Dict[str, Any] = {
-            "role": self.role_map[message.role],
+            "role": self.role_map[message.role] if self.role_map else self.default_role_map[message.role],
             "content": message.content,
             "name": message.name,
             "tool_call_id": message.tool_call_id,
@@ -295,7 +313,7 @@ class OpenAIChat(Model):
         response_format: Optional[Union[Dict, Type[BaseModel]]] = None,
         tools: Optional[List[Dict[str, Any]]] = None,
         tool_choice: Optional[Union[str, Dict[str, Any]]] = None,
-    ) -> Union[ChatCompletion, ParsedChatCompletion]:
+    ) -> ChatCompletion:
         """
         Send a chat completion request to the OpenAI API.
 
@@ -307,17 +325,6 @@ class OpenAIChat(Model):
         """
 
         try:
-            if (
-                response_format is not None
-                and isinstance(response_format, type)
-                and issubclass(response_format, BaseModel)
-            ):
-                return self.get_client().beta.chat.completions.parse(
-                    model=self.id,
-                    messages=[self._format_message(m) for m in messages],  # type: ignore
-                    **self.get_request_kwargs(response_format=response_format, tools=tools, tool_choice=tool_choice),
-                )
-
             return self.get_client().chat.completions.create(
                 model=self.id,
                 messages=[self._format_message(m) for m in messages],  # type: ignore
@@ -367,7 +374,7 @@ class OpenAIChat(Model):
         response_format: Optional[Union[Dict, Type[BaseModel]]] = None,
         tools: Optional[List[Dict[str, Any]]] = None,
         tool_choice: Optional[Union[str, Dict[str, Any]]] = None,
-    ) -> Union[ChatCompletion, ParsedChatCompletion]:
+    ) -> ChatCompletion:
         """
         Sends an asynchronous chat completion request to the OpenAI API.
 
@@ -378,16 +385,6 @@ class OpenAIChat(Model):
             ChatCompletion: The chat completion response from the API.
         """
         try:
-            if (
-                response_format is not None
-                and isinstance(response_format, type)
-                and issubclass(response_format, BaseModel)
-            ):
-                return await self.get_async_client().beta.chat.completions.parse(
-                    model=self.id,
-                    messages=[self._format_message(m) for m in messages],  # type: ignore
-                    **self.get_request_kwargs(response_format=response_format, tools=tools, tool_choice=tool_choice),
-                )
             return await self.get_async_client().chat.completions.create(
                 model=self.id,
                 messages=[self._format_message(m) for m in messages],  # type: ignore
@@ -602,7 +599,7 @@ class OpenAIChat(Model):
 
     def parse_provider_response(
         self,
-        response: Union[ChatCompletion, ParsedChatCompletion],
+        response: ChatCompletion,
         response_format: Optional[Union[Dict, Type[BaseModel]]] = None,
     ) -> ModelResponse:
         """
@@ -620,19 +617,6 @@ class OpenAIChat(Model):
         # Get response message
         response_message = response.choices[0].message
 
-        # Parse structured outputs if enabled
-        try:
-            if (
-                response_format is not None
-                and isinstance(response_format, type)
-                and issubclass(response_format, BaseModel)
-            ):
-                parsed_object = response_message.parsed  # type: ignore
-                if parsed_object is not None:
-                    model_response.parsed = parsed_object
-        except Exception as e:
-            log_warning(f"Error retrieving structured outputs: {e}")
-
         # Add role
         if response_message.role is not None:
             model_response.role = response_message.role
