@@ -7,6 +7,7 @@ from pydantic import BaseModel
 
 from agno.media import AudioArtifact, AudioResponse, ImageArtifact, VideoArtifact
 from agno.models.message import Citations, Message, MessageReferences
+from agno.models.response import ToolExecution
 from agno.reasoning.step import ReasoningStep
 from agno.utils.log import logger
 
@@ -19,12 +20,19 @@ class RunEvent(str, Enum):
     run_completed = "RunCompleted"
     run_error = "RunError"
     run_cancelled = "RunCancelled"
+
+    run_paused = "RunPaused"
+    run_continued = "RunContinued"
+
     tool_call_started = "ToolCallStarted"
     tool_call_completed = "ToolCallCompleted"
+
     reasoning_started = "ReasoningStarted"
     reasoning_step = "ReasoningStep"
     reasoning_completed = "ReasoningCompleted"
+
     updating_memory = "UpdatingMemory"
+
     workflow_started = "WorkflowStarted"
     workflow_completed = "WorkflowCompleted"
 
@@ -53,9 +61,6 @@ class RunResponseExtraData:
         add_messages = data.pop("add_messages", None)
         add_messages = [Message.model_validate(message) for message in add_messages] if add_messages else None
 
-        history = data.pop("history", None)
-        history = [Message.model_validate(message) for message in history] if history else None
-
         reasoning_steps = data.pop("reasoning_steps", None)
         reasoning_steps = [ReasoningStep.model_validate(step) for step in reasoning_steps] if reasoning_steps else None
 
@@ -87,11 +92,12 @@ class RunResponse:
     messages: Optional[List[Message]] = None
     metrics: Optional[Dict[str, Any]] = None
     model: Optional[str] = None
+    model_provider: Optional[str] = None
     run_id: Optional[str] = None
     agent_id: Optional[str] = None
     session_id: Optional[str] = None
     workflow_id: Optional[str] = None
-    tools: Optional[List[Dict[str, Any]]] = None
+    tools: Optional[List[ToolExecution]] = None
     formatted_tool_calls: Optional[List[str]] = None
     images: Optional[List[ImageArtifact]] = None  # Images attached to the response
     videos: Optional[List[VideoArtifact]] = None  # Videos attached to the response
@@ -101,12 +107,30 @@ class RunResponse:
     extra_data: Optional[RunResponseExtraData] = None
     created_at: int = field(default_factory=lambda: int(time()))
 
+    @property
+    def is_paused(self):
+        if self.event == RunEvent.run_paused:
+            return True
+        return False
+
+    @property
+    def tools_requiring_confirmation(self):
+        return [t for t in self.tools if t.requires_confirmation] if self.tools else []
+
+    @property
+    def tools_requiring_user_input(self):
+        return [t for t in self.tools if t.requires_user_input] if self.tools else []
+
+    @property
+    def tools_awaiting_external_execution(self):
+        return [t for t in self.tools if t.external_execution_required] if self.tools else []
+
     def to_dict(self) -> Dict[str, Any]:
         _dict = {
             k: v
             for k, v in asdict(self).items()
             if v is not None
-            and k not in ["messages", "extra_data", "images", "videos", "audio", "response_audio", "citations"]
+            and k not in ["messages", "tools", "extra_data", "images", "videos", "audio", "response_audio", "citations"]
         }
         if self.messages is not None:
             _dict["messages"] = [m.to_dict() for m in self.messages]
@@ -153,7 +177,15 @@ class RunResponse:
                 _dict["citations"] = self.citations
 
         if self.content and isinstance(self.content, BaseModel):
-            _dict["content"] = self.content.model_dump(exclude_none=True)
+            _dict["content"] = self.content.model_dump(exclude_none=True, mode="json")
+
+        if self.tools is not None:
+            _dict["tools"] = []
+            for tool in self.tools:
+                if isinstance(tool, ToolExecution):
+                    _dict["tools"].append(tool.to_dict())
+                else:
+                    _dict["tools"].append(tool)
 
         return _dict
 
@@ -173,7 +205,22 @@ class RunResponse:
         messages = data.pop("messages", None)
         messages = [Message.model_validate(message) for message in messages] if messages else None
 
-        return cls(messages=messages, **data)
+        tools = data.pop("tools", None)
+        tools = [ToolExecution.from_dict(tool) for tool in tools] if tools else None
+
+        images = data.pop("images", None)
+        images = [ImageArtifact.model_validate(image) for image in images] if images else None
+
+        videos = data.pop("videos", None)
+        videos = [VideoArtifact.model_validate(video) for video in videos] if videos else None
+
+        audio = data.pop("audio", None)
+        audio = [AudioArtifact.model_validate(audio) for audio in audio] if audio else None
+
+        response_audio = data.pop("response_audio", None)
+        response_audio = AudioResponse.model_validate(response_audio) if response_audio else None
+
+        return cls(messages=messages, tools=tools, images=images, videos=videos, response_audio=response_audio, **data)
 
     def get_content_as_string(self, **kwargs) -> str:
         import json
