@@ -1,3 +1,5 @@
+from typing import Any, List
+
 from agno.tools import Toolkit
 
 try:
@@ -10,11 +12,18 @@ class AWSLambdaTools(Toolkit):
     name: str = "AWSLambdaTool"
     description: str = "A tool for interacting with AWS Lambda functions"
 
-    def __init__(self, region_name: str = "us-east-1", **kwargs):
-        super().__init__(name="aws-lambda", **kwargs)
+    def __init__(
+        self,
+        region_name: str = "us-east-1",
+        **kwargs,
+    ):
         self.client = boto3.client("lambda", region_name=region_name)
-        self.register(self.list_functions)
-        self.register(self.invoke_function)
+
+        tools: List[Any] = []
+        tools.append(self.list_functions)
+        tools.append(self.invoke_function)
+
+        super().__init__(name="aws-lambda", tools=tools, **kwargs)
 
     def list_functions(self) -> str:
         try:
