@@ -165,20 +165,26 @@ class MCPTools(Toolkit):
             if "url" not in sse_params:
                 sse_params["url"] = self.url
             self._context = sse_client(**sse_params)
+            client_timeout = min(self.timeout_seconds, sse_params.get("timeout", self.timeout_seconds))
         elif self.transport == "streamable-http":
             streamable_http_params = asdict(self.server_params) if self.server_params is not None else {}
             if "url" not in streamable_http_params:
                 streamable_http_params["url"] = self.url
             self._context = streamablehttp_client(**streamable_http_params)
-        elif self.transport == "stdio":
+            params_timeout = streamable_http_params.get("timeout", self.timeout_seconds)
+            if isinstance(params_timeout, timedelta):
+                params_timeout = int(params_timeout.total_seconds())
+            client_timeout = min(self.timeout_seconds, params_timeout)
+        else:
             if self.server_params is None:
                 raise ValueError("server_params must be provided when using stdio transport.")
             self._context = stdio_client(self.server_params)  # type: ignore
+            client_timeout = self.timeout_seconds
 
         session_params = await self._context.__aenter__()  # type: ignore
         read, write = session_params[0:2]
 
-        self._session_context = ClientSession(read, write, read_timeout_seconds=timedelta(seconds=self.timeout_seconds))  # type: ignore
+        self._session_context = ClientSession(read, write, read_timeout_seconds=timedelta(seconds=client_timeout))
         self.session = await self._session_context.__aenter__()  # type: ignore
 
         # Initialize with the new session
