@@ -6,9 +6,10 @@ from agno.utils.log import log_info
 
 class SleepTools(Toolkit):
     def __init__(self, **kwargs):
-        super().__init__(name="sleep", **kwargs)
+        tools = []
+        tools.append(self.sleep)
 
-        self.register(self.sleep)
+        super().__init__(name="sleep", tools=tools, **kwargs)
 
     def sleep(self, seconds: int) -> str:
         """Use this function to sleep for a given number of seconds."""
