@@ -63,4 +63,4 @@ def get_entrypoint_for_tool(tool: MCPTool, session: ClientSession):
             log_exception(f"Failed to call MCP tool '{tool_name}': {e}")
             return f"Error: {e}"
 
-    return partial(call_tool, tool_name=tool.name, tool_description=tool.description)
+    return partial(call_tool, tool_name=tool.name)
