@@ -1,4 +1,5 @@
 import json
+from dataclasses import dataclass, field
 from typing import Any, Dict, List, Optional, Tuple
 
 from agno.media import File, Image
@@ -13,6 +14,22 @@ try:
 except ImportError:
     raise ImportError("`anthropic` not installed. Please install using `pip install anthropic`")
 
+
+@dataclass
+class MCPToolConfiguration:
+    enabled: bool = True
+    allowed_tools: List[str] = field(default_factory=list)
+
+
+@dataclass
+class MCPServerConfiguration:
+    type: str
+    url: str
+    name: str
+    tool_configuration: Optional[MCPToolConfiguration] = None
+    authorization_token: Optional[str] = None
+
+
 ROLE_MAP = {
     "system": "system",
     "user": "user",
@@ -50,6 +67,10 @@ def _format_image_for_message(image: Image) -> Optional[Dict[str, Any]]:
     }
 
     try:
+        # Case 0: Image is an Anthropic uploaded file
+        if image.content is not None and hasattr(image.content, "id"):
+            return {"type": "image", "source": {"type": "file", "file_id": image.content.id}}
+
         # Case 1: Image is a URL
         if image.url is not None:
             return {"type": "image", "source": {"type": "url", "url": image.url}}
@@ -117,6 +138,16 @@ def _format_file_for_message(file: File) -> Optional[Dict[str, Any]]:
         "text/plain": "text",
     }
 
+    # Case 0: File is an Anthropic uploaded file
+    if file.external is not None and hasattr(file.external, "id"):
+        return {
+            "type": "document",
+            "source": {
+                "type": "file",
+                "file_id": file.external.id,
+            },
+        }
+
     # Case 1: Document is a URL
     if file.url is not None:
         return {
@@ -231,7 +262,7 @@ def format_messages(messages: List[Message]) -> Tuple[List[Dict[str, str]], str]
 
                 content.append(RedactedThinkingBlock(data=message.redacted_thinking, type="redacted_thinking"))
 
-            if isinstance(message.content, str) and message.content:
+            if isinstance(message.content, str) and message.content and len(message.content.strip()) > 0:
                 content.append(TextBlock(text=message.content, type="text"))
 
             if message.tool_calls:
