@@ -1 +1,5 @@
 from agno.vectordb.cassandra.cassandra import Cassandra
+
+__all__ = [
+    "Cassandra",
+]
